==> nextcloud-14.0.1.tgz: nextcloud/apps/dav/l10n/it.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Cose da fare",
    "Personal" : "Personale",
    "{actor} created calendar {calendar}" : "{actor} ha creato il calendario {calendar}",
    "You created calendar {calendar}" : "Hai creato il calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ha eliminato il calendario {calendar}",
    "You deleted calendar {calendar}" : "Hai eliminato il calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ha aggiornato il calendario {calendar}",
    "You updated calendar {calendar}" : "Hai aggiornato il calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Hai condiviso il calendario {calendar} come collegamento pubblico",
    "You removed public link for calendar {calendar}" : "Hai rimosso il collegamento pubblico per il calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha condiviso il calendario {calendar} con te",
    "You shared calendar {calendar} with {user}" : "Hai condiviso il calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ha aggiornato il calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha rimosso la condivisione del calendario {calendar} con te",
    "You unshared calendar {calendar} from {user}" : "Hai rimosso la condivisione del calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} ha rimosso la condivisione del calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} ha rimosso la condivisione del calendario {calendar} con se stesso",
    "You shared calendar {calendar} with group {group}" : "Hai condiviso il calendario {calendar} con il gruppo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ha condiviso il calendario {calendar} con il gruppo {group}",
    "You unshared calendar {calendar} from group {group}" : "Hai rimosso la condivisione del calendario {calendar} con il gruppo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} ha rimosso la condivisione del calendario {calendar} con il gruppo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ha creato l'evento {event} nel calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Hai creato l'evento {event} nel calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ha eliminato l'evento {event} dal calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Hai ha eliminato l'evento {event} dal calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} ha aggiornato l'evento {event} nel calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Hai aggiornato l'evento {event} nel calendario {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} ha creato la cosa da fare {todo} nell'elenco {calendar}",
    "You created todo {todo} in list {calendar}" : "Hai creato la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} ha eliminato la cosa da fare {todo} dall'elenco {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Hai eliminato la cosa da fare {todo} dall'elenco {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ha aggiornato la cosa da fare {todo} nell'elenco {calendar}",
    "You updated todo {todo} in list {calendar}" : "Hai aggiornato la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} ha risolto la cosa da fare {todo} nell'elenco {calendar}",
    "You solved todo {todo} in list {calendar}" : "Hai risolto la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} ha riaperto la cosa da fare {todo} nell'elenco {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Hai riaperto la cosa da fare {todo} nell'elenco {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> è stato modificato",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario è stato modificato",
    "A calendar <strong>todo</strong> was modified" : "Una <strong>cosa da fare</strong> del calendario è stata modificata",
    "Contact birthdays" : "Date di nascita dei contatti",
    "%s via %s" : "%s tramite %s",
    "Invitation canceled" : "Invito annullato",
    "Hello %s," : "Ciao %s,",
    "The meeting »%s« with %s was canceled." : "L'incontro «%s» con %s è stato annullato.",
    "Invitation updated" : "Invito aggiornato",
    "The meeting »%s« with %s was updated." : "L'incontro «%s» con %s è stato aggiornato.",
    "%s invited you to »%s«" : "%s ti ha invitato a «%s»",
    "When:" : "Quando:",
    "Where:" : "Dove:",
    "Description:" : "Descrizione:",
    "Link:" : "Collegamento:",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "More options …" : "Altre opzioni...",
    "More options at %s" : "Altre opzioni alle %s",
    "Contacts" : "Contatti",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Terminatore WebDAV",
    "Technical details" : "Dettagli tecnici",
    "Remote Address: %s" : "Indirizzo remoto: %s",
    "Request ID: %s" : "ID richiesta: %s",
    "There was an error updating your attendance status." : "Si è verificato un errore durante l'aggiornamento dello stato della tua partecipazione.",
    "Please contact the organizer directly." : "Contatta direttamente l'amministratore.",
    "Are you accepting the invitation?" : "Accetti l'invito?",
    "Tentative" : "Provvisorio",
    "Save" : "Salva",
    "Your attendance was updated successfully." : "La tua partecipazione è stata aggiornata correttamente.",
    "Calendar server" : "Server di calendari",
    "Send invitations to attendees" : "Invia gli inviti ai partecipanti",
    "Please make sure to properly set up the email settings above." : "Assicurati di configurare correttamente le impostazioni di posta sopra.",
    "Automatically generate a birthday calendar" : "Genera automaticamente un calendario dei compleanni",
    "Birthday calendars will be generated by a background job." : "Il calendario dei compleanni sarà generato con un'operazione in background.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Per cui non saranno disponibili immediatamente dopo l'abilitazione, ma saranno mostrati dopo qualche istante.",
    "CalDAV server" : "Server CalDAV"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/dav/l10n/it.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Cose da fare",
    "Personal" : "Personale",
    "{actor} created calendar {calendar}" : "{actor} ha creato il calendario {calendar}",
    "You created calendar {calendar}" : "Hai creato il calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ha eliminato il calendario {calendar}",
    "You deleted calendar {calendar}" : "Hai eliminato il calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ha aggiornato il calendario {calendar}",
    "You updated calendar {calendar}" : "Hai aggiornato il calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Hai condiviso il calendario {calendar} come collegamento pubblico",
    "You removed public link for calendar {calendar}" : "Hai rimosso il collegamento pubblico per il calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha condiviso il calendario {calendar} con te",
    "You shared calendar {calendar} with {user}" : "Hai condiviso il calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ha aggiornato il calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha rimosso la condivisione del calendario {calendar} con te",
    "You unshared calendar {calendar} from {user}" : "Hai rimosso la condivisione del calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} ha rimosso la condivisione del calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} ha rimosso la condivisione del calendario {calendar} con se stesso",
    "You shared calendar {calendar} with group {group}" : "Hai condiviso il calendario {calendar} con il gruppo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ha condiviso il calendario {calendar} con il gruppo {group}",
    "You unshared calendar {calendar} from group {group}" : "Hai rimosso la condivisione del calendario {calendar} con il gruppo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} ha rimosso la condivisione del calendario {calendar} con il gruppo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ha creato l'evento {event} nel calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Hai creato l'evento {event} nel calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ha eliminato l'evento {event} dal calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Hai ha eliminato l'evento {event} dal calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} ha aggiornato l'evento {event} nel calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Hai aggiornato l'evento {event} nel calendario {calendar}",
    "Busy" : "Occupato",
    "{actor} created todo {todo} in list {calendar}" : "{actor} ha creato la cosa da fare {todo} nell'elenco {calendar}",
    "You created todo {todo} in list {calendar}" : "Hai creato la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} ha eliminato la cosa da fare {todo} dall'elenco {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Hai eliminato la cosa da fare {todo} dall'elenco {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ha aggiornato la cosa da fare {todo} nell'elenco {calendar}",
    "You updated todo {todo} in list {calendar}" : "Hai aggiornato la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} ha risolto la cosa da fare {todo} nell'elenco {calendar}",
    "You solved todo {todo} in list {calendar}" : "Hai risolto la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} ha riaperto la cosa da fare {todo} nell'elenco {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Hai riaperto la cosa da fare {todo} nell'elenco {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> è stato modificato",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario è stato modificato",
    "A calendar <strong>todo</strong> was modified" : "Una <strong>cosa da fare</strong> del calendario è stata modificata",
    "Death of %s" : "Morte di %s",
    "Contact birthdays" : "Date di nascita dei contatti",
    "Calendar:" : "Calendario:",
    "Date:" : "Data:",
    "Where:" : "Dove:",
    "Description:" : "Descrizione:",
    "Untitled event" : "Evento senza titolo",
    "_%n year_::_%n years_" : ["%n anno","%n anni"],
    "_%n month_::_%n months_" : ["%n mese","%n mesi"],
    "_%n day_::_%n days_" : ["%n giorno","%n giorni"],
    "_%n hour_::_%n hours_" : ["%n ora","%n ore"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minuti"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (%s fa)",
    "Calendar: %s" : "Calendario: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descrizione: %s",
    "Where: %s" : "Dove: %s",
    "%1$s via %2$s" : "%1$s tramite %2$s",
    "Invitation canceled" : "Invito annullato",
    "Hello %s," : "Ciao %s,",
    "The meeting »%1$s« with %2$s was canceled." : "L'incontro «%1$s» con %2$s è stato annullato.",
    "Invitation updated" : "Invito aggiornato",
    "The meeting »%1$s« with %2$s was updated." : "L'incontro «%1$s» con %2$s è stato aggiornato.",
    "%1$s invited you to »%2$s«" : "%1$s ti ha invitato a «%2$s»",
    "When:" : "Quando:",
    "Link:" : "Collegamento:",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "More options …" : "Altre opzioni...",
    "More options at %s" : "Altre opzioni alle %s",
    "Contacts" : "Contatti",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Il tuo %s deve essere configurato all'uso di HTTPS per poter usare CalDAV e CardDAV con iOS/macOS.",
    "Configures a CalDAV account" : "Configura un account CalDAV",
    "Configures a CardDAV account" : "Configura un account CardDAV",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Terminatore WebDAV",
    "There was an error updating your attendance status." : "Si è verificato un errore durante l'aggiornamento dello stato della tua partecipazione.",
    "Please contact the organizer directly." : "Contatta direttamente l'amministratore.",
    "Are you accepting the invitation?" : "Accetti l'invito?",
    "Tentative" : "Provvisorio",
    "Save" : "Salva",
    "Your attendance was updated successfully." : "La tua partecipazione è stata aggiornata correttamente.",
    "Calendar server" : "Server di calendari",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installa anche {calendarappstoreopen}l'applicazione Calendario{linkclose}, o {calendardocopen}connetti il tuo desktop e mobile per la sincronizzazione ↗{linkclose}.",
    "Send invitations to attendees" : "Invia gli inviti ai partecipanti",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Assicurati di configurare correttamente {emailopen}il server di posta{linkclose}.",
    "Automatically generate a birthday calendar" : "Genera automaticamente un calendario dei compleanni",
    "Birthday calendars will be generated by a background job." : "Il calendario dei compleanni sarà generato con un'operazione in background.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Per cui non saranno disponibili immediatamente dopo l'abilitazione, ma saranno mostrati dopo qualche istante.",
    "Send notifications for events" : "Invia notifiche per eventi",
    "Notifications are sent via background jobs, so these must occur often enough." : "Le notifiche saranno inviate tramite operazioni in background, per cui tali operazioni devono essere eseguite abbastanza spesso.",
    "Enable notifications for events via push" : "Abilita notifiche per eventi tramite push",
    "Technical details" : "Dettagli tecnici",
    "Remote Address: %s" : "Indirizzo remoto: %s",
    "Request ID: %s" : "ID richiesta: %s",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Le notifiche saranno inviate tramite operazioni in background, per cui devono verificarsi abbastanza spesso."
},
"nplurals=2; plural=(n != 1);");
